pipewire_python._constants API documentation

Edit on GitHub

# pipewire_python._constants

Here we store constant values, don't expect to see something here in documentation html version.

View Source

     1"""
     2Here we store constant values, don't expect
     3to see something here in documentation html version.
     4"""
     5
     6MESSAGES_ERROR = {
     7    "NotImplementedError": "This function is not yet implemented",
     8    "ValueError": "The value entered is wrong",
     9}
    10
    11RECOMMENDED_RATES = [
    12    8000,
    13    11025,
    14    16000,
    15    22050,
    16    44100,
    17    48000,
    18    88200,
    19    96000,
    20    176400,
    21    192000,
    22    352800,
    23    384000,
    24]
    25
    26RECOMMENDED_FORMATS = ["u8", "s8", "s16", "s32", "f32", "f64"]